##  Processing Time
Calculations aren't processed instantly. The processing time depends on the number of targeted fact sheets. Calculation cards display the number of fact sheets currently in the queue.
  * Large queues: For queues with more than 100,000 fact sheets, processing can take significantly longer, potentially extending up to several hours. In extreme cases, processing may take up to 24 hours.
  * New calculations: When you create and activate a new calculation, it triggers a recalculation for all targeted fact sheets and their relations, which can result in longer processing times. If you need to recalculate a field on a specific fact sheet, update the needed fields on that fact sheet. This approach can lead to faster processing times as the recalculation is limited to the specific fact sheet rather than all targeted fact sheets and their relations.


![Calculation card showing 44 fact sheets in queue and status as active.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9ac99198d80648c7b7346b32be036132_LowRes.png)
Number of Fact Sheets in the Queue on a Calculation Card
